
$::data = { 'Test1' => 'works',
	  'TestFloat' => '1.3312',
	  'TestName' => 'JOHN Q. SMITH',
	  'TestEscape' => '&;"#<>',
	  'TestCase' => 'bOoK',
	  'TestDate' => 900043200,
	  'TestFruit' => 'apple',
	  'TestParagraph' => 'The quick brown snuffle-uppagus jumped '.
			     'scr-ump-dilly-iciously over the lazy supercalifragilisticexpialidocious bug.'
};


